pub struct MockDevicesApi {
DevicesApi_expectations: MockDevicesApi_DevicesApi,
}Fields
DevicesApi_expectations: MockDevicesApi_DevicesApiImplementations
Sourceimpl MockDevicesApi
impl MockDevicesApi
Sourcepub fn checkpoint(&mut self)
pub fn checkpoint(&mut self)
Validate that all current expectations for all methods have been satisfied, and discard them.
Sourcepub fn new() -> Self
pub fn new() -> Self
Create a new mock object with no expectations.
This method will not be generated if the real struct
already has a new method. However, it will be
generated if the struct implements a trait with a new
method. The trait’s new method can still be called
like <MockX as TraitY>::new
Sourceimpl MockDevicesApi
impl MockDevicesApi
Sourcepub fn expect_deactivate(&mut self) -> &mut Expectation
pub fn expect_deactivate(&mut self) -> &mut Expectation
Create an Expectation for mocking the deactivate method
Sourcepub fn expect_get(&mut self) -> &mut Expectation
pub fn expect_get(&mut self) -> &mut Expectation
Create an Expectation for mocking the get method
Sourcepub fn expect_get_all(&mut self) -> &mut Expectation
pub fn expect_get_all(&mut self) -> &mut Expectation
Create an Expectation for mocking the get_all method
Sourcepub fn expect_get_by_identifier(&mut self) -> &mut Expectation
pub fn expect_get_by_identifier(&mut self) -> &mut Expectation
Create an Expectation for mocking the get_by_identifier method
Sourcepub fn expect_get_by_identifier_query(&mut self) -> &mut Expectation
pub fn expect_get_by_identifier_query(&mut self) -> &mut Expectation
Create an Expectation for mocking the get_by_identifier_query method
Sourcepub fn expect_post(&mut self) -> &mut Expectation
pub fn expect_post(&mut self) -> &mut Expectation
Create an Expectation for mocking the post method
Sourcepub fn expect_post_lost_trust(&mut self) -> &mut Expectation
pub fn expect_post_lost_trust(&mut self) -> &mut Expectation
Create an Expectation for mocking the post_lost_trust method
Sourcepub fn expect_post_untrust(&mut self) -> &mut Expectation
pub fn expect_post_untrust(&mut self) -> &mut Expectation
Create an Expectation for mocking the post_untrust method
Sourcepub fn expect_post_update_trust(&mut self) -> &mut Expectation
pub fn expect_post_update_trust(&mut self) -> &mut Expectation
Create an Expectation for mocking the post_update_trust method
Sourcepub fn expect_put(&mut self) -> &mut Expectation
pub fn expect_put(&mut self) -> &mut Expectation
Create an Expectation for mocking the put method
Sourcepub fn expect_put_clear_token(&mut self) -> &mut Expectation
pub fn expect_put_clear_token(&mut self) -> &mut Expectation
Create an Expectation for mocking the put_clear_token method
Sourcepub fn expect_put_keys(&mut self) -> &mut Expectation
pub fn expect_put_keys(&mut self) -> &mut Expectation
Create an Expectation for mocking the put_keys method
Sourcepub fn expect_put_token(&mut self) -> &mut Expectation
pub fn expect_put_token(&mut self) -> &mut Expectation
Create an Expectation for mocking the put_token method
Sourcepub fn expect_put_web_push_auth(&mut self) -> &mut Expectation
pub fn expect_put_web_push_auth(&mut self) -> &mut Expectation
Create an Expectation for mocking the put_web_push_auth method